/*
 * Reference Patch: Derating Cores on Apalis iMX8
 *
 * This patch provides a reference implementation for modifying device tree
 * entries to derate cores on the Apalis iMX8. It removes certain operating
 * points (OPPs) to reduce power consumption or limit performance.
 *
 * License: MIT No Attribution (MIT-0)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this patch and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * SPDX-License-Identifier: MIT-0
 *
 * Author: Bruno Mello <bruno.mello@toradex.com>
 * Date: 2025-04-07
 *
 * Changelog:
 * - Removed overdrive and high-frequency OPP entries to limit max performance
 * - Adjusted GPU operating points to remove aggressive frequency scaling
 * - Ensured patch is safe to apply as a non-functional reference
 */



diff --git a/arch/arm64/boot/dts/freescale/imx8qm-ss-gpu.dtsi b/arch/arm64/boot/dts/freescale/imx8qm-ss-gpu.dtsi
index 90b670b15276..4571c2ec496c 100644
--- a/arch/arm64/boot/dts/freescale/imx8qm-ss-gpu.dtsi
+++ b/arch/arm64/boot/dts/freescale/imx8qm-ss-gpu.dtsi
@@ -18,8 +18,6 @@ imx8_gpu_ss: imx8_gpu1_ss {
 		depth-compression = <0>;
 		/*<freq-kHz vol-uV>*/
 		operating-points = <
-			/*overdrive*/  800000  0  /*The first tuple is for core clock frequency*/
-				1000000 0  /*The second tuple is for shader clock frequency*/
 			/*nominal*/    650000  0
 				700000  0
 			/*underdrive*/ 400000  0  /*core/shader clock share the same frequency on underdrive mode*/
diff --git a/arch/arm64/boot/dts/freescale/imx8qm.dtsi b/arch/arm64/boot/dts/freescale/imx8qm.dtsi
index c3fdee60b9c6..769a0ec7d58e 100755
--- a/arch/arm64/boot/dts/freescale/imx8qm.dtsi
+++ b/arch/arm64/boot/dts/freescale/imx8qm.dtsi
@@ -219,13 +219,6 @@ opp-1296000000 {
 			opp-microvolt = <1100000>;
 			clock-latency-ns = <150000>;
 		};
-
-		opp-1596000000 {
-			opp-hz = /bits/ 64 <1596000000>;
-			opp-microvolt = <1100000>;
-			clock-latency-ns = <150000>;
-			opp-suspend;
-		};
 	};
 
 	gic: interrupt-controller@51a00000 {
